# eda

Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by ketto (c) 2023

## Examples of How To Use (Buggy Alpha Version)

Creating A Server

```python
# hello world
print("Hello World")

```